@@ -6,12 +6,12 @@
 #' @seealso \code{\link{to_factor}} to convert numeric vectors into factors;
 #'            \code{\link{rec}} to recode variables.
 #'
-#' @param lvl Eiher numeric, indicating the new reference level, or a string,
+#' @param lvl Either numeric, indicating the new reference level, or a string,
 #'   indicating the value label from the new reference level. If \code{x} is a
 #'   factor with non-numeric factor levels, \code{relevel(x, ref = lvl)} is
 #'   returned. See 'Examples'.
 #'
-#' @inheritParams to_factor
+#' @inheritParams to_dummy
 #'
 #' @return \code{x} with new reference level. If \code{x}
 #'           is a data frame, the complete data frame \code{x} will be returned,
@@ -60,7 +60,6 @@
 #' levels(ref_lvl(iris$Species, lvl = 3))
 #' levels(ref_lvl(iris$Species, lvl = "versicolor"))
 #'
-#' @importFrom tibble as_tibble
 #' @importFrom dplyr quos
 #' @export
 ref_lvl <- function(x, ..., lvl = NULL) {
@@ -73,8 +72,6 @@ ref_lvl <- function(x, ..., lvl = NULL) {
     for (i in colnames(.dat)) {
       x[[i]] <- ref_lvl_helper(.dat[[i]], value = lvl)
     }
-    # coerce to tibble
-    x <- tibble::as_tibble(x)
   } else {
     x <- ref_lvl_helper(.dat, value = lvl)
   }
@@ -108,7 +105,7 @@ ref_lvl_helper <- function(x, value) {
     lab.values <- sjlabelled::get_labels(
       x,
       attr.only = TRUE,
-      include.values = "n",
+      values = "n",
       drop.na = TRUE
     )
     vals <- as.numeric(names(lab.values))
